@@ -44,28 +44,32 @@ def send_iffy_edit(prompt: str, code: Dict[str, str], clipboard: bool = False, y
     if clipboard:
         full_prompt += dedent("""
         
-        Answer in the following format:
+        Answer in the following format, using '> ' to indent values:
         
         explanation:
         > <The changes that you made>
         code:
         > <the code to be output line 1>
-        > <the code to be output, line n...>""")
+        > <the code to be output, line n...>
+        
+        You must include an explanation of what you did, and the code to be output, regardless of the format or file.""")
 
     else:
         full_prompt += dedent("""
 
-        You may only output complete files.
-
-        If you add or modify a file, return it in this exact format:
+        You may only send me complete files.
 
+        For each file, return one block in this format, using '> ' to indent values:
+        
         filename:
         > <the filename to be output>
         explanation:
         > <The changes that you made>
         code:
         > <code line 1>
-        > <code line n...>""")
+        > <code line n...>
+        
+        You must include the filename, an explanation of what you did, and the code for the file to be output, regardless of the format or file.""")
 
     max_tokens = confirm_send(full_prompt, yes=yes, silent=clipboard)
 
@@ -84,6 +88,19 @@ def send_iffy_edit(prompt: str, code: Dict[str, str], clipboard: bool = False, y
         print(response["choices"][0]["text"])
     return parsed[0] if clipboard else parsed
 
+def send_normal_completion(prompt, max_tokens=3000, yes=False):
+
+    max_tokens = confirm_send(prompt, max_tokens, yes=yes)
+
+    response = openai.Completion.create(
+        engine="text-davinci-003",
+        prompt=prompt,
+        max_tokens=max_tokens,
+        n=1,
+        temperature=0.6,
+    )
+
+    return response["choices"][0]["text"].strip().strip("```").strip()
 
 
 if __name__ == "__main__":
